pub fn harden_process() -> ResultExpand description
Performs all possible stable hardening steps for the platform. This uses the
default configuration, so unstable hardening methods are disabled regardless
of the unstable crate feature.
Errors
Returns an error when one of the available hardening steps error due to a system or libc interface returning an error. In case of error it is recommended to issue an error and shut down the application without loading secrets into memory.