pub fn check_tracer_procfs() -> ResultExpand description
Check whether a tracer is attached via the procfs virtual filesystem.
- Type: anti-tracing
- Targets: linux
- API: procfs (stable)
Errors
Returns an error when the required procfs file /proc/self/status could not
be opened, or if it doesn’t contain a valid TracerPid entry. Returns
BeingTraced when the process is being traced.